@@ -14,6 +14,7 @@ import sklearn.mixture
 import xml.etree.ElementTree as ET
 from PIL import Image, ImageDraw, ImageFont
 import re
+from pathlib import Path
 
 
 '''
@@ -86,7 +87,7 @@ import re
 
 class ANA():
     def __init__(self, directory):
-        self.directory = directory
+        self.directory = Path(directory)
         self._filelist()
         if not self.files:
             print('scalar_data files not in HDF format.  Run xml2hdf to convert.')
@@ -94,12 +95,12 @@ class ANA():
         self.parameters()
 
     def spec_map(self):
-        tree = ET.parse(self.directory + '//spec_maps')
+        tree = ET.parse(self.directory / "spec_maps")
         root = tree.getroot()
 
         maps = root.findall('element')
 
-        im = Image.open(self.directory + '//experiment.png')
+        im = Image.open(self.directory / "experiment.png")
         draw = ImageDraw.Draw(im)
         font = ImageFont.truetype("arial", 16)
         sz = 10
@@ -113,11 +114,11 @@ class ANA():
             w, h = draw.textsize(str(i + 1))
             draw.text((cx - w/2, cy - h/2), str(i + 1), font=font, anchor='SE')
 
-        im.save(self.directory + '//exp_loc.png')
+        im.save(self.directory / "exp_loc.png")
         self.spec_image = im
 
     def parameters(self):
-        tree = ET.parse(self.directory + '//spec_maps')
+        tree = ET.parse(self.directory / 'spec_maps')
         root = tree.getroot()
 
         maps = root.findall('element')
@@ -138,7 +139,7 @@ class ANA():
             rampS.append(float(m.find('forward_').find('ramp_speed_').text))
             maxF.append(float(m.find('forward_').find('maximum_force_').text))
 
-        tree = ET.parse(self.directory + '//measurement')
+        tree = ET.parse(self.directory / 'measurement')
         root = tree.getroot()
 
         maps = root.findall('measurement')
@@ -199,8 +200,8 @@ class ANA():
         return d.groupby(['Channel', 'Backward']).Value.describe()
 
     def xml2hdf(self):
-        f1 = glob(self.directory + '//scalar*')
-        f2 = glob(self.directory + '//scalar*.h5')
+        f1 = glob(str(self.directory / 'scalar*'))
+        f2 = glob(str(self.directory / 'scalar*.h5'))
         
         files = [f for f in f1 if f not in f2]
         
@@ -310,9 +311,10 @@ class ANA():
         plt.title(channel)
         plt.xlabel(label)
         plt.ylabel('Counts')
+        return n, bin_centers
 
-    def gaussianMix(self, spots, channel, backward, number=1, lim=None, scale=None):
-        gmm = sklearn.mixture.GaussianMixture(n_components=number, covariance_type='diag')
+    def gaussianMix(self, spots, channel, backward, number=1, lim=None, scale=None, **kwargs):
+        gmm = sklearn.mixture.GaussianMixture(n_components=number, covariance_type='diag', **kwargs)
         d = self.channelData(spots, channel, backward).Value.values
         if scale:
             d /= scale
@@ -329,7 +331,7 @@ class ANA():
         return fits
 
     def _filelist(self):
-        self.files = glob(self.directory + '\\scalar*.h5')
+        self.files = [str(file) for file in sorted(self.directory.glob('scalar*.h5'))]
         self.files.sort(key=self._natural_keys)
     
     # sorts list numerically
